Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(714)

Unified Diff: src/interpreter/interpreter.h

Issue 1901083002: [Interpreter] Introduce IncStub and DecStub. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/interpreter/interpreter.h
diff --git a/src/interpreter/interpreter.h b/src/interpreter/interpreter.h
index 155b2b5abee577c3517f97031259907aec21cd15..caa33f4ecd5cea5642481a07dfbe53c5611c89f0 100644
--- a/src/interpreter/interpreter.h
+++ b/src/interpreter/interpreter.h
@@ -73,9 +73,8 @@ class Interpreter {
void DoBinaryOp(Runtime::FunctionId function_id,
InterpreterAssembler* assembler);
- // Generates code to perform the count operations via |function_id|.
- void DoCountOp(Runtime::FunctionId function_id,
- InterpreterAssembler* assembler);
+ // Generates code to perform the count operations via |callable|.
+ void DoCountOp(Callable callable, InterpreterAssembler* assembler);
// Generates code to perform the comparison operation associated with
// |compare_op|.
@@ -120,7 +119,7 @@ class Interpreter {
// Generates code to perform a type conversion.
void DoTypeConversionOp(Callable callable, InterpreterAssembler* assembler);
- // Generates code ro create a literal via |function_id|.
+ // Generates code to create a literal via |function_id|.
void DoCreateLiteral(Runtime::FunctionId function_id,
InterpreterAssembler* assembler);

Powered by Google App Engine
This is Rietveld 408576698